@@ -107,7 +107,6 @@ pref("mail.check_time",                     10);
 pref("mail.pop_name",                       "");
 pref("mail.remember_password",              false);
 pref("mail.pop_password",                   "");
-pref("mail.auto_quote",                     true);
 pref("mail.fixed_width_messages",           true);
 pref("mail.citation_color",                 ""); // quoted color
 pref("mail.quoted_style",                   0); // 0=plain, 1=bold, 2=italic, 3=bolditalic
@@ -142,9 +141,9 @@ pref("mail.addr_book.displayName.lastnamefirst", "chrome://messenger/locale/mess
 pref("mail.addr_book.show_phonetic_fields", "chrome://messenger/locale/messenger.properties");
 pref("mail.attach_vcard",                   false);
 pref("mail.html_compose",                   true);
-// you can specify one, option header
+// you can specify multiple, option headers
 // this will show up in the address picker in the compose window
-// examples: "X-Face" or "Approved"
+// examples: "X-Face" or "Approved,X-No-Archive"
 pref("mail.compose.other.header",	    "");
 pref("mail.fcc_folder",                     "");
 pref("mail.encrypt_outgoing_mail",          false);
@@ -174,8 +173,6 @@ pref("news.mark_old_read",                  false);
 pref("mailnews.wraplength",                 72);
 pref("mail.compose.wrap_to_window_width",   false);
 
-pref("mailnews.reply_on_top",               0); // 0=bottom 1=top 2=select+bottom 3=select+top
-
 // 0=no header, 1="<author> wrote:", 2="On <date> <author> wrote:", 3="<author> wrote On <date>:", 4=user specified
 pref("mailnews.reply_header_type",          1);
 // locale which affects date format, set empty string to use application default locale
@@ -206,6 +203,8 @@ pref("mailnews.search_date_separator",     "chrome://messenger/locale/messenger.
 
 pref("mailnews.language_sensitive_font",    true);
 
+pref("mailnews.quotingPrefs.version",       0);  // used to decide whether to migrate global quoting prefs
+
 pref("offline.news.download.unread_only",   true);
 pref("offline.news.download.by_date",       true);
 pref("offline.news.download.days",          30);    // days
@@ -295,6 +294,8 @@ pref("mail.toolbars.showbutton.junk", true);
 pref("mail.toolbars.showbutton.print",false);
 pref("mail.toolbars.showbutton.stop", false);
 
+pref("mailnews.thread_pane_column_unthreads", true);
+
 pref("mailnews.account_central_page.url", "chrome://messenger/locale/messenger.properties");
 
 /* default prefs for Mozilla 5.0 */
@@ -309,6 +310,14 @@ pref("mail.identity.default.draft_folder","mailbox://nobody@Local%20Folders/Draf
 pref("mail.identity.default.stationery_folder","mailbox://nobody@Local%20Folders/Templates");
 pref("mail.identity.default.directoryServer","");
 pref("mail.identity.default.overrideGlobal_Pref", false);
+pref("mail.identity.default.auto_quote", true);
+pref("mail.identity.default.reply_on_top", 0); // 0=bottom 1=top 2=select
+pref("mail.identity.default.sig_bottom", true); // true=below quoted false=above quoted
+// Headers to always add to outgoing mail
+// examples: "header1,header2"
+// pref("mail.identity.id1.headers", "header1");
+// user_pref("mail.identity.id1.header.header1", "X-Mozilla-Rocks: True")
+pref("mail.identity.default.headers", "");
 
 // by default, only collect addresses the user sends to (outgoing)
 // incoming is all spam anyways
@@ -326,6 +335,8 @@ pref("mail.server.default.offline_support_level", -1);
 pref("mail.server.default.leave_on_server", false);
 pref("mail.server.default.download_on_biff", false);
 pref("mail.server.default.check_time", 10);
+pref("mail.server.default.delete_by_age_from_server", false);
+pref("mail.server.default.num_days_to_leave_on_server", 7);
 // "mail.server.default.check_new_mail" now lives in the protocol info
 pref("mail.server.default.dot_fix", true);
 pref("mail.server.default.limit_offline_message_size", false);
@@ -335,6 +346,7 @@ pref("mail.server.default.delete_mail_left_on_server", false);
 pref("mail.server.default.valid", true);
 pref("mail.server.default.abbreviate",true);
 pref("mail.server.default.isSecure", false);
+pref("mail.server.default.useSecAuth", false);
 pref("mail.server.default.override_namespaces", true);
 
 pref("mail.server.default.delete_model", 1);
@@ -342,6 +354,7 @@ pref("mail.server.default.fetch_by_chunks", true);
 pref("mail.server.default.mime_parts_on_demand", true);
 
 pref("mail.server.default.always_authenticate",false);
+pref("mail.server.default.singleSignon", true);
 pref("mail.server.default.max_articles", 500);
 pref("mail.server.default.notify.on", true);
 pref("mail.server.default.mark_old_read", false);
@@ -370,18 +383,22 @@ pref("mail.server.default.whiteListAbURI","moz-abmdbdirectory://abook.mab");  //
 pref("mail.server.default.purgeSpam",false);
 pref("mail.server.default.purgeSpamInterval",14); // 14 days
 pref("mail.server.default.spamLoggingEnabled",false);
+pref("mail.server.default.manualMark",false);
+pref("mail.server.default.manualMarkMode",0); // 0 == "move to junk folder", 1 == "delete"
 
 pref("mail.smtpserver.default.auth_method", 1); // auth any
+pref("mail.smtpserver.default.trySecAuth", true);
 pref("mail.smtpserver.default.try_ssl", 0);
 
 // For the next 3 prefs, see <http://www.bucksch.org/1/projects/mozilla/16507>
 pref("mail.display_glyph", true);   // TXT->HTML :-) etc. in viewer
 pref("mail.display_struct", true);  // TXT->HTML *bold* etc. in viewer; ditto
 pref("mail.send_struct", false);   // HTML->HTML *bold* etc. during Send; ditto
+pref("mailnews.display.original_date", false);   // display date string from mail headers without interpreting
 // For the next 4 prefs, see <http://www.bucksch.org/1/projects/mozilla/108153>
 pref("mailnews.display.prefer_plaintext", false);  // Ignore HTML parts in multipart/alternative
 pref("mailnews.display.html_as", 0);  // How to display HTML parts. 0 = Render the sender's HTML; 1 = HTML->TXT->HTML; 2 = Show HTML source; 3 = Sanitize HTML
-pref("mailnews.display.html_sanitizer.allowed_tags", "html head title body p br div(lang,title) h1 h2 h3 h4 h5 h6 ul ol li(value,start,compact) dl dt dd blockquote(type,cite) pre noscript noframes strong em sub sup span(lang,title) acronym(title) abbr(title) del(title,cite,datetime) ins(title,cite,datetime) q(cite) a(href,name,title) img(alt,title,longdesc,src) base(href) area(alt) applet(alt) object(alt) var samp dfn address kbd code cite s strike tt b i table(align) caption tr(align,valign) td(rowspan,colspan,align,valign) th(rowspan,colspan,align,valign)");
+pref("mailnews.display.html_sanitizer.allowed_tags", "html head title body p br div(lang,title) h1 h2 h3 h4 h5 h6 ul(type,compact) ol(type,compact,start) li(type,value) dl dt dd blockquote(type,cite) pre noscript noframes strong em sub sup span(lang,title) acronym(title) abbr(title) del(title,cite,datetime) ins(title,cite,datetime) q(cite) a(href,name,title) img(alt,title,longdesc,src) base(href) area(alt) applet(alt) object(alt) var samp dfn address kbd code cite s strike tt b i table(align) caption tr(align,valign) td(rowspan,colspan,align,valign) th(rowspan,colspan,align,valign)");
 pref("mailnews.display.disallow_mime_handlers", 0);  /* Let only a few classes process incoming data. This protects from bugs (e.g. buffer overflows) and from security loopholes (e.g. allowing unchecked HTML in some obscure classes, although the user has html_as > 0).
 This option is mainly for the UI of html_as.
 0 = allow all available classes
@@ -417,6 +434,8 @@ pref("mailnews.html_domains","");
 pref("mailnews.plaintext_domains","");
 pref("mailnews.global_html_domains.version",1);
 
+pref("mail.imap.use_status_for_biff", true);
+
 // Pref controlling the updates on the pre-configured accounts.
 // In order to add new pre-configured accounts (after a version),
 // increase the following version number besides updating the
@@ -442,6 +461,8 @@ pref("mail.content_disposition_type", 0);
 pref("mailnews.show_send_progress", true); //Will show a progress dialog when saving or sending a message
 pref("mail.server.default.retainBy", 1);
 
+pref("mailnews.ui.junk.firstuse", true);
+
 // for manual upgrades of certain UI features.
 // 1 -> 2 is for the folder pane tree landing, to hide the
 // unread and total columns, see msgMail3PaneWindow.js
@@ -526,6 +547,10 @@ pref("mail.compose.add_undisclosed_recipients", true);
 pref("mail.purge.min_delay",480);
 pref("mail.purge.timer_interval",5); 
 
+// require a password before showing imap or local headers in thread pane
+pref("mail.password_protect_local_cache", false);
 // to reduce forking in the js / C++
 // overridden by stand alone mail
 pref("mail.standalone", false);
+
+pref("mailnews.view.last",0); // 0 == "all" view
